How to contribute
=================

We want Iris and its sister packages (such as iris-grib) to be driven by
the community - your contributions are invaluable to us! This page lists
the guidelines for contributors which will help ease the process of
getting your hard work accepted into iris-grib, and shared back to the world.

Getting started
---------------

1. If you've not already got one, sign up for a
   [GitHub account](https://github.com/signup/free).
2. Fork the iris-grib repository, create your new fix/feature branch, and
   start committing code.
 - The main
   [Iris development guide](https://scitools-iris.readthedocs.io/en/latest/developers_guide/gitwash/index.html)
   has more detail.
3. Remember to add appropriate documentation and tests to supplement any new or changed functionality.


Submitting changes
------------------

1. Push your branch to your fork of iris-grib.
2. Submit your pull request.
3. Note that all authors on pull requests will automatically be asked to sign the 
   [SciTools Contributor Licence Agreement](https://cla-assistant.io/SciTools/)
   (CLA), if they have not already done so. 
4. Sit back and wait for the core iris-grib development team to review
   your code.


If in doubt, please
[contact us](https://groups.google.com/forum/?fromgroups=#!forum/scitools-iris)
on our Google Group, and we'll be happy to help you.
